
import { useState, useEffect, useMemo } from 'react'
import Taro from '@tarojs/taro'
import goback from '@/assets/comm/goback.png'

import './style.less'
import { View } from '@tarojs/components'

export default (props) => {
  const { logo,home, title = '首页', noback } = props

  // 菜单胶囊
  const menuBound = useMemo(() => Taro.getMenuButtonBoundingClientRect(), [])
  // 整体顶部导航
  const navStyle = useMemo(() => {
    return {
      height: `${menuBound.bottom + 8}px`,
    }
  }, [menuBound.bottom])
  // 导航栏
  const navBarStyle = useMemo(() => {
    return {
      top: `${menuBound.top}px`,
      height: `${menuBound.height}px`
    }
  }, [menuBound.top, menuBound.height])
  // 导航栏按钮
  const actionStyle = useMemo(() => {
    return {
      width: `${menuBound.width + 8}px`,
      paddingLeft: '8px',
      lineHeight: `${menuBound.height}px`,
      height: `${menuBound.height}px`,
    }
  }, [menuBound.width, menuBound.height])
  // 导航栏标题
  const contentStyle = useMemo(() => {
    const screenWidth = menuBound.right + 8;
    return {
      width: `${screenWidth - menuBound.width * 2 - 16}px`,
      lineHeight: `${menuBound.height}px`,
      height: `${menuBound.height}px`,
      paddingLeft: '8px',
      paddingRight: '8px',
    }
  }, [menuBound.width, menuBound.height, menuBound.right])

  const handleAction = () => {
    if (home || logo) return;

    if (Taro.getCurrentPages().length > 1) {
      Taro.navigateBack({ delta: 1 })
    }
  }

  useEffect(() => {
    if (title) {
      Taro.setNavigationBarTitle({ title })
    }
  }, [title])

  return (
    <view className='custom-nav' style={navStyle}>
      <view className='custom-nav-bar' style={navBarStyle}>
        <view className='custom-nav-bar-action' style={actionStyle}>
          {
            !logo && !home && (
              !noback && (
                <View style={{ width: '100%', height: '100%' }} onClick={handleAction}>
                  <image className='goback' src={goback} />
                </View>
              )
            )
          }
        </view>
        <view className='custom-nav-bar-content' style={contentStyle}>{title}</view>
      </view>
    </view>
  )
}
